PowerShell Katılma Yolu | PowerShell Birleştirme Yolu Örnekleri


PowerShell Katılım Yoluna Giriş

Aşağıdaki makalede PowerShell Birleştirme Yolu için bir taslak sunulmaktadır. Kullanıcının iki yolu tek bir yolda birleştirmek isteyebileceği senaryolar olabilir; bu durumda kullanıcının birleştirme yolu cmdlet'ini kullanması gerekir. Bir ana yol olacaktır ve yeni bir yol oluşturmak için ana yola birden fazla alt yol eklenebilir. Bu, birkaçını saymak gerekirse, kayıt defteri, dosya sistemi ve sertifikalar gibi çeşitli sağlayıcılarla birlikte kullanılabilir. Yol parametresi, yolu PowerShell tarafından kolayca tanınabilecek bir biçimde yönetir ve döndürür. Burada çeşitli parametreler ve birden fazla yolu birleştirmenin yolları hakkında ayrıntılı olarak göreceğiz.

PowerShell Birleştirme Yolunun Sözdizimi

Birleştirme Yolu cmdlet'inin sözdizimi aşağıdaki gibidir:

Ad:

Join-Path

Sözdizimi:

Join-Path [-Path] <string[]> [-ChildPath] <string> [-Resolve] [-Credential <pscredential>] [-UseTransaction]
[<CommonParameters>]

Takma adlar:

None

Örnek:

Kod:

Write-Host "Demo of join path" -ForegroundColor Green
$path1="test"
$path2="test1"
Write-Host "Path one is " $path1
Write-Host "Path two is" $path2
Write-Host "Combined path is" -ForegroundColor Green
Join-Path -Path $path1 -ChildPath $path2

Çıktı:

Parametreler:

  • -AdditionalPath: Bu parametrenin veri türü String[]'dir. Bu, yola eklenmesi gereken ekstra değerleri temsil eder. Bu parametre isteğe bağlı ve belirtilmiş olsa da alt yol parametresinin bir değerle sunulması gerekir. Bu parametre kullanılarak sınırsız sayıda yol birleştirilebilir. Bu parametrenin cmdlet'teki konumu 2'dir. Yok, bu parametrenin varsayılan değeridir. Boru hattı girişini kabul eder, ancak bu parametre joker karakterleri desteklemez.
  • -ChildPath: Bu parametre zorunludur. Bu, yol parametresinin değerine eklenecek bir değeri temsil eder. Cmdlet'teki konumu birdir. Bu parametrenin veri türü bir dizedir. Yok, varsayılan değeridir. Hem joker karakterleri hem de boru hattı girişini kabul eder.
  • -Kimlik bilgisi: Bu parametre yalnızca kimliğe bürünme amacıyla kullanılır. Veri türü PSCredential'tır ve isteğe bağlı bir veridir. Varsayılan değer hiçbiridir. Bu işlem hattı girişini kabul edebilir ancak joker karakterlere izin verilmez.
  • -Yol: Bu, alt yolların ekleneceği ana yol değerini temsil eder. Bu zorunlu bir parametredir. Veri türü String[] ve takma adı PSPath'tir. Bu parametrenin cmdlet içindeki konumu 0'dır. Varsayılan değer none'dur. Hem ardışık düzen girişini kabul eder hem de joker karakterlere izin verilir.
  • -Resolve: Bu, birleştirilmiş yolu çözümlemek için geçerli sağlayıcının kullanılması gerektiğini cmdlet'e belirtir. Joker karakterlerin sağlanması durumunda cmdlet, birleştirilen yolla hizalanan tüm yolu döndürür. Joker karakterler kullanılmazsa eşleşme olmaması durumunda hata atılır. Bu parametrenin veri türü bir anahtardır. Bu isteğe bağlı bir parametredir. Varsayılan değer hiçbiridir. Boru hattı girişini ve joker karakterleri kabul etmez.

PowerShell Birleştirme Yolu Örnekleri

Aşağıda PowerShell Birleştirme Yolu örnekleri verilmiştir:

Örnek #1

Bir ana yola ve bir alt yola katılma.

Kod:

Write-Host "Welcome to the demo of joining one parent and one child path" -ForegroundColor Green
$parentpath=Read-Host "Enter the parent path"
$childpath= Read-Host "Enter the child path"
Write-Host "Combined path is as follows" -ForegroundColor Green
Join-Path -Path $parentpath -ChildPath $childpath

Çıktı:

Örnek #2

Çözümleme ve joker karakterlerini kullanarak birleştirilmiş yolun içeriğini görüntüleyin.

Kod:

Write-Host "Demo of using resolve parameter" -ForegroundColor Green
Write-Host "Demo of providing wild card matches in both parent and child" -ForegroundColor Green
$parent= Read-Host "Enter the parent path with wildcard"
$childp= Read-Host "Enter the child path with wildcard"
Write-Host "Display the contents using the join-path" -ForegroundColor Green
Join-Path $parent $childp -Resolve

Çıktı:

Yukarıdaki örnekte, ana yol c:\vignesh\t* değeriyle sağlanmıştır; bu, Vignesh klasörünün içinde olduğu anlamına gelir; t ile başlayan her alt klasör, verilen “*” alt yolunda ana değer olarak kabul edilir. her şeyi ifade eder. Dolayısıyla çıktı, koşulla eşleşen tüm dosyaların bir listesinin görüntüsüdür.

Örnek #3

Ek Yol Parametresinin Kullanımı.

Kod:

Write-Host "Welcome to demo of additional child path in Join-path" -ForegroundColor Green
$mainpath= Read-Host "Enter the main path value"
$cpath= Read-Host "Enter the child path value"
$apath1= Read-Host "Enter the additional path one"
$apath2 = Read-Host "enter the additional path two"
$apath3 = Read-Host "enter the additional path three"
$apath4 = Read-Host "enter the additional path four"
$apath5 = Read-Host "enter the additional path five"
Write-Host "Joining all the path" -ForegroundColor Green
$path = Join-Path -Path $mainpath -ChildPath $cpath -AdditionalChildPaths($apath1, $apath2,$apath3,$apath4,$apath5)
Write-Host "the joined path is" -ForegroundColor Green

Çıktı:

Bu cmdlet tarafından desteklenen sağlayıcıların listesini bulmak için get-psprovider cmdlet'ini çalıştırarak bunları tanımlayabiliriz.

Geçerli oturumda desteklenen sağlayıcılar aşağıdadır:

Örnek #4

İşlem hattını kullanarak birden çok yolu birleştirme.

Kod:

Write-Host "Welcome to demo of joining path using pipeline input" -ForegroundColor Green
$mainpath= Read-Host "Enter the main path value"
$cpath= Read-Host "Enter the child path value"
$apath1= Read-Host "Enter the additional path one"
$apath2 = Read-Host "enter the additional path two"
$apath3 = Read-Host "enter the additional path three"
$apath4 = Read-Host "enter the additional path four"
$apath5 = Read-Host "enter the additional path five"
Write-Host "Joining all the path using pipeline input" -ForegroundColor Green
Join-Path $mainpath | Join-Path -ChildPath $cpath | Join-Path -ChildPath $apath1 | Join-Path -ChildPath $apath2 | Join-Path -ChildPath $apath3 | Join-Path -ChildPath $apath4 | Join-Path -ChildPath $apath5

Çıktı:

Yukarıdaki cmdlet'e katılırken alt yol parametresi belirtilirse, cmdlet'in ardışık düzen girişini kabul etmediğini belirten bir hata atılacaktır. Bunun gerçekleşmemesi için, ikinci yoldan itibaren tüm yolların önüne alt yol parametresi konulmalıdır.

Çözüm

Bu nedenle makale, join-path cmdlet'i ve onun çeşitli zorunlu ve isteğe bağlı parametreleriyle ilgili ayrıntıları kapsıyordu. Ayrıca, join-path cmdlet'ini kullanarak farklı şekillerde birleştirme yollarının çeşitli örneklerini de gösterdi.

İlgili makaleler